@@ -3,6 +3,9 @@ from typing import Dict, Optional
 from ciphey.iface import Checker, Config, ParamSpec, T, registry
 from loguru import logger
 from pywhat import identifier
+from rich.console import Console
+
+console = Console()
 
 
 @registry.register
@@ -10,13 +13,17 @@ class What(Checker[str]):
 
     """
     Uses PyWhat to determine plaintext with regexes
+    https://github.com/bee-san/pyWhat
     """
 
     def check(self, ctext: T) -> Optional[str]:
         logger.trace("Trying PyWhat checker")
         returned_regexes = self.id.identify(ctext, api=True)
         if len(returned_regexes["Regexes"]) > 0:
-            return returned_regexes["Regexes"][0]["Regex Pattern"]["Name"]
+            console.print(
+                f'\nI think the plaintext is a [yellow]{returned_regexes["Regexes"][0]["Regex Pattern"]["Name"]}[/yellow].'
+            )
+            return f'The plaintext is a [yellow]{returned_regexes["Regexes"][0]["Regex Pattern"]["Name"]}[/yellow].'
         return None
 
     def getExpectedRuntime(self, text: T) -> float:
