@@ -18,7 +18,7 @@ from typing import Any, Optional, Union
 import click
 from appdirs import AppDirs
 from loguru import logger
-from rich import print
+from rich.console import Console
 from yaspin import yaspin
 from yaspin.spinners import Spinners
 
@@ -26,6 +26,8 @@ from . import iface
 
 warnings.filterwarnings("ignore")
 
+console = Console()
+
 
 def decrypt(config: iface.Config, ctext: Any) -> Union[str, bytes]:
     """A simple alias for searching a ctext and makes the answer pretty"""
@@ -264,4 +266,4 @@ def main(**kwargs):
     if result is None:
         result = "Could not find any solutions."
 
-    print(result)
+    console.print(result)
